"""
GUI File Format Converter
"""

# version
__major__ = 1
__minor__ = 8
__release__ = 0
__prerelease__ = "" # alpha, beta, rc etc.

# package information
__name__ = "ffmulticonverter"
__version__ = "{0}.{1}.{2}".format(__major__, __minor__, __release__)
__version__ += __prerelease__
__description__ = __doc__
__author__ = "Ilias Stamatis"
__author_email__ = "stamatis.iliass@gmail.com"
__license__ = "GNU GPL3"
__platforms__ = "Linux"
__url__ = "https://sites.google.com/site/ffmulticonverter/"
__download_url__ = "https://sourceforge.net/projects/ffmulticonv/files/"
